==> de.uka.ipd.sdq.pcm.codegen.simucom.source_1.0.0.201511051246.jar: de/uka/ipd/sdq/pcm/codegen/simucom/transformations/sim/SimCalculatorsXpt.java <==
package de.uka.ipd.sdq.pcm.codegen.simucom.transformations.sim;

import com.google.inject.Inject;
import de.uka.ipd.sdq.pcm.codegen.simucom.transformations.CalculatorsXpt;
import de.uka.ipd.sdq.pcm.codegen.simucom.transformations.JavaNamesExt;
import de.uka.ipd.sdq.pcm.codegen.simucom.transformations.PCMext;
import de.uka.ipd.sdq.pcm.codegen.simucom.transformations.SensorsExt;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import org.eclipse.emf.cdo.CDOObject;
import org.eclipse.emf.common.util.EList;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.CollectionLiterals;
import org.eclipse.xtext.xbase.lib.Extension;
import org.palladiosimulator.pcm.repository.BasicComponent;
import org.palladiosimulator.pcm.repository.InfrastructureSignature;
import org.palladiosimulator.pcm.repository.OperationSignature;
import org.palladiosimulator.pcm.repository.RepositoryComponent;
import org.palladiosimulator.pcm.repository.Signature;
import org.palladiosimulator.pcm.seff.AbstractAction;
import org.palladiosimulator.pcm.seff.ExternalCallAction;
import org.palladiosimulator.pcm.seff.InternalAction;
import org.palladiosimulator.pcm.seff.ResourceDemandingSEFF;
import org.palladiosimulator.pcm.seff.ServiceEffectSpecification;
import org.palladiosimulator.pcm.seff.StartAction;
import org.palladiosimulator.pcm.seff.seff_performance.InfrastructureCall;
import org.palladiosimulator.pcm.usagemodel.EntryLevelSystemCall;
import org.palladiosimulator.pcm.usagemodel.UsageScenario;

@SuppressWarnings("all")
public class SimCalculatorsXpt extends CalculatorsXpt {
  @Inject
  @Extension
  private JavaNamesExt _javaNamesExt;
  
  @Inject
  @Extension
  private PCMext _pCMext;
  
  @Inject
  @Extension
  private SensorsExt _sensorsExt;
  
  protected String _setupCalculators(final UsageScenario us) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("\t");
    _builder.append("if(getModel().getConfiguration().getSimulateFailures()){");
    _builder.newLine();
    _builder.append("\t\t");
    CharSequence _setupCalculatorExecutionResult = this.setupCalculatorExecutionResult(us);
    _builder.append(_setupCalculatorExecutionResult, "\t\t");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.newLine();
    {
      List<EntryLevelSystemCall> _querySystemCalls = this._pCMext.querySystemCalls(us);
      for(final EntryLevelSystemCall systemCall : _querySystemCalls) {
        _builder.append("\t");
        String _setupCalculators = this.setupCalculators(systemCall);
        _builder.append(_setupCalculators, "\t");
        _builder.newLineIfNotEmpty();
      }
    }
    return _builder.toString();
  }
  
  protected String _setupCalculators(final EntryLevelSystemCall call) {
    StringConcatenation _builder = new StringConcatenation();
    OperationSignature _operationSignature__EntryLevelSystemCall = call.getOperationSignature__EntryLevelSystemCall();
    String _javaSignature = this._javaNamesExt.javaSignature(_operationSignature__EntryLevelSystemCall);
    String _plus = ("Call_" + _javaSignature);
    String _plus_1 = (_plus + " <EntryLevelSystemCall id: ");
    String _id = call.getId();
    String _plus_2 = (_plus_1 + _id);
    final String callName = (_plus_2 + " >");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("// Setup calculator for system call ");
    String _entityName = call.getEntityName();
    _builder.append(_entityName, "\t");
    _builder.append(" (");
    String _id_1 = call.getId();
    _builder.append(_id_1, "\t");
    _builder.append(")");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    CharSequence _setupCalculatorResponseTime = this.setupCalculatorResponseTime(callName, ("start" + callName), ("end" + callName));
    _builder.append(_setupCalculatorResponseTime, "\t");
    _builder.newLineIfNotEmpty();
    return _builder.toString();
  }
  
  protected String _setupCalculators(final RepositoryComponent comp) {
    StringConcatenation _builder = new StringConcatenation();
    {
      if ((comp instanceof BasicComponent)) {
        {
          EList<ServiceEffectSpecification> _serviceEffectSpecifications__BasicComponent = ((BasicComponent) comp).getServiceEffectSpecifications__BasicComponent();
          for(final ServiceEffectSpecification seff : _serviceEffectSpecifications__BasicComponent) {
            String _setupCalculators = this.setupCalculators(seff);
            _builder.append(_setupCalculators, "");
            _builder.newLineIfNotEmpty();
          }
        }
      } else {
      }
    }
    return _builder.toString();
  }
  
  protected String _setupCalculators(final ServiceEffectSpecification seff) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("\t\t");
    _builder.newLine();
    return _builder.toString();
  }
  
  protected String _setupCalculators(final ResourceDemandingSEFF seff) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("// Setup calculators for service call ");
    Signature _describedService__SEFF = seff.getDescribedService__SEFF();
    String _entityName = _describedService__SEFF.getEntityName();
    _builder.append(_entityName, "");
    _builder.append(",");
    _builder.newLineIfNotEmpty();
    {
      EList<AbstractAction> _steps_Behaviour = seff.getSteps_Behaviour();
      StartAction _findStart = this._pCMext.findStart(_steps_Behaviour);
      ArrayList<ExternalCallAction> _newArrayList = CollectionLiterals.<ExternalCallAction>newArrayList();
      List<ExternalCallAction> _queryExternalCallActions = this._pCMext.queryExternalCallActions(_findStart, _newArrayList);
      for(final ExternalCallAction callAction : _queryExternalCallActions) {
        String _setupCalculators = this.setupCalculators(callAction);
        _builder.append(_setupCalculators, "");
        _builder.append(" ");
        _builder.newLineIfNotEmpty();
      }
    }
    {
      EList<AbstractAction> _steps_Behaviour_1 = seff.getSteps_Behaviour();
      StartAction _findStart_1 = this._pCMext.findStart(_steps_Behaviour_1);
      ArrayList<InternalAction> _newArrayList_1 = CollectionLiterals.<InternalAction>newArrayList();
      List<InternalAction> _queryInternalActions = this._pCMext.queryInternalActions(_findStart_1, _newArrayList_1);
      for(final InternalAction callAction_1 : _queryInternalActions) {
        String _setupCalculators_1 = this.setupCalculators(callAction_1);
        _builder.append(_setupCalculators_1, "");
        _builder.newLineIfNotEmpty();
      }
    }
    return _builder.toString();
  }
  
  protected String _setupCalculators(final ExternalCallAction action) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("// Old: \"Call \"+this.calledService_ExternalService.interface__OperationSignature.entityName+\".\"+this.calledService_ExternalService.javaSignature()+\" <AssemblyCtx: \\\"+this.assemblyContext.getId()+\\\", CallID: \"+ this.id +\">\"");
    _builder.newLine();
    OperationSignature _calledService_ExternalService = action.getCalledService_ExternalService();
    final String callName = this._sensorsExt.externalCallActionDescription(_calledService_ExternalService, action);
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("// ExternalCallAction ");
    String _entityName = action.getEntityName();
    _builder.append(_entityName, "\t");
    _builder.append(" (");
    String _id = action.getId();
    _builder.append(_id, "\t");
    _builder.append(")");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    CharSequence _setupCalculatorResponseTime = this.setupCalculatorResponseTime(callName, ("start" + callName), ("end" + callName));
    _builder.append(_setupCalculatorResponseTime, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("if(getModel().getConfiguration().getSimulateFailures()){");
    _builder.newLine();
    _builder.append("\t\t");
    CharSequence _setupCalculatorExecutionResult = this.setupCalculatorExecutionResult(action, callName);
    _builder.append(_setupCalculatorExecutionResult, "\t\t");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    return _builder.toString();
  }
  
  protected String _setupCalculators(final InternalAction action) {
    StringConcatenation _builder = new StringConcatenation();
    {
      EList<InfrastructureCall> _infrastructureCall__Action = action.getInfrastructureCall__Action();
      for(final InfrastructureCall infrastructureCall : _infrastructureCall__Action) {
        InfrastructureSignature _signature__InfrastructureCall = infrastructureCall.getSignature__InfrastructureCall();
        final String callName = this._sensorsExt.internalActionDescription(_signature__InfrastructureCall, action);
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("// InternalAction ");
        String _entityName = action.getEntityName();
        _builder.append(_entityName, "\t");
        _builder.append(" (");
        String _id = action.getId();
        _builder.append(_id, "\t");
        _builder.append(")");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        CharSequence _setupCalculatorResponseTime = this.setupCalculatorResponseTime(callName, ("start" + callName), ("end" + callName));
        _builder.append(_setupCalculatorResponseTime, "\t");
        _builder.newLineIfNotEmpty();
      }
    }
    return _builder.toString();
  }
  
  public String setupCalculators(final CDOObject comp) {
    if (comp instanceof RepositoryComponent) {
      return _setupCalculators((RepositoryComponent)comp);
    } else if (comp instanceof ExternalCallAction) {
      return _setupCalculators((ExternalCallAction)comp);
    } else if (comp instanceof InternalAction) {
      return _setupCalculators((InternalAction)comp);
    } else if (comp instanceof EntryLevelSystemCall) {
      return _setupCalculators((EntryLevelSystemCall)comp);
    } else if (comp instanceof ResourceDemandingSEFF) {
      return _setupCalculators((ResourceDemandingSEFF)comp);
    } else if (comp instanceof UsageScenario) {
      return _setupCalculators((UsageScenario)comp);
    } else if (comp instanceof ServiceEffectSpecification) {
      return _setupCalculators((ServiceEffectSpecification)comp);
    } else {
      throw new IllegalArgumentException("Unhandled parameter types: " +
        Arrays.<Object>asList(comp).toString());
    }
  }
}

==> de.uka.ipd.sdq.pcm.codegen.simucom.source_6.0.0.202602010113.jar: de/uka/ipd/sdq/pcm/codegen/simucom/transformations/sim/SimCalculatorsXpt.java <==
package de.uka.ipd.sdq.pcm.codegen.simucom.transformations.sim;

import com.google.inject.Inject;
import de.uka.ipd.sdq.pcm.codegen.simucom.transformations.CalculatorsXpt;
import de.uka.ipd.sdq.pcm.codegen.simucom.transformations.JavaNamesExt;
import de.uka.ipd.sdq.pcm.codegen.simucom.transformations.PCMext;
import de.uka.ipd.sdq.pcm.codegen.simucom.transformations.SensorsExt;
import java.util.Arrays;
import java.util.List;
import org.eclipse.emf.common.util.EList;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.CollectionLiterals;
import org.eclipse.xtext.xbase.lib.Extension;
import org.palladiosimulator.pcm.repository.BasicComponent;
import org.palladiosimulator.pcm.repository.RepositoryComponent;
import org.palladiosimulator.pcm.seff.ExternalCallAction;
import org.palladiosimulator.pcm.seff.InternalAction;
import org.palladiosimulator.pcm.seff.ResourceDemandingSEFF;
import org.palladiosimulator.pcm.seff.ServiceEffectSpecification;
import org.palladiosimulator.pcm.seff.seff_performance.InfrastructureCall;
import org.palladiosimulator.pcm.usagemodel.EntryLevelSystemCall;
import org.palladiosimulator.pcm.usagemodel.UsageScenario;

@SuppressWarnings("all")
public class SimCalculatorsXpt extends CalculatorsXpt {
  @Inject
  @Extension
  private JavaNamesExt _javaNamesExt;

  @Inject
  @Extension
  private PCMext _pCMext;

  @Inject
  @Extension
  private SensorsExt _sensorsExt;

  protected String _setupCalculators(final UsageScenario us) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("\t");
    _builder.append("if(getModel().getConfiguration().getSimulateFailures()){");
    _builder.newLine();
    _builder.append("\t\t");
    CharSequence _setupCalculatorExecutionResult = this.setupCalculatorExecutionResult(us);
    _builder.append(_setupCalculatorExecutionResult, "\t\t");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    _builder.newLine();
    {
      List<EntryLevelSystemCall> _querySystemCalls = this._pCMext.querySystemCalls(us);
      for(final EntryLevelSystemCall systemCall : _querySystemCalls) {
        _builder.append("\t");
        String _setupCalculators = this.setupCalculators(systemCall);
        _builder.append(_setupCalculators, "\t");
        _builder.newLineIfNotEmpty();
      }
    }
    return _builder.toString();
  }

  protected String _setupCalculators(final EntryLevelSystemCall call) {
    StringConcatenation _builder = new StringConcatenation();
    String _javaSignature = this._javaNamesExt.javaSignature(call.getOperationSignature__EntryLevelSystemCall());
    String _plus = ("Call_" + _javaSignature);
    String _plus_1 = (_plus + " <EntryLevelSystemCall id: ");
    String _id = call.getId();
    String _plus_2 = (_plus_1 + _id);
    final String callName = (_plus_2 + " >");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("// Setup calculator for system call ");
    String _entityName = call.getEntityName();
    _builder.append(_entityName, "\t");
    _builder.append(" (");
    String _id_1 = call.getId();
    _builder.append(_id_1, "\t");
    _builder.append(")");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    CharSequence _setupCalculatorResponseTime = this.setupCalculatorResponseTime(callName, ("start" + callName), ("end" + callName));
    _builder.append(_setupCalculatorResponseTime, "\t");
    _builder.newLineIfNotEmpty();
    return _builder.toString();
  }

  protected String _setupCalculators(final RepositoryComponent comp) {
    StringConcatenation _builder = new StringConcatenation();
    {
      if ((comp instanceof BasicComponent)) {
        {
          EList<ServiceEffectSpecification> _serviceEffectSpecifications__BasicComponent = ((BasicComponent) comp).getServiceEffectSpecifications__BasicComponent();
          for(final ServiceEffectSpecification seff : _serviceEffectSpecifications__BasicComponent) {
            String _setupCalculators = this.setupCalculators(seff);
            _builder.append(_setupCalculators);
            _builder.newLineIfNotEmpty();
          }
        }
      } else {
      }
    }
    return _builder.toString();
  }

  protected String _setupCalculators(final ServiceEffectSpecification seff) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("\t\t");
    _builder.newLine();
    return _builder.toString();
  }

  protected String _setupCalculators(final ResourceDemandingSEFF seff) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("// Setup calculators for service call ");
    String _entityName = seff.getDescribedService__SEFF().getEntityName();
    _builder.append(_entityName);
    _builder.append(",");
    _builder.newLineIfNotEmpty();
    {
      List<ExternalCallAction> _queryExternalCallActions = this._pCMext.queryExternalCallActions(this._pCMext.findStart(seff.getSteps_Behaviour()), CollectionLiterals.<ExternalCallAction>newArrayList());
      for(final ExternalCallAction callAction : _queryExternalCallActions) {
        String _setupCalculators = this.setupCalculators(callAction);
        _builder.append(_setupCalculators);
        _builder.append(" ");
        _builder.newLineIfNotEmpty();
      }
    }
    {
      List<InternalAction> _queryInternalActions = this._pCMext.queryInternalActions(this._pCMext.findStart(seff.getSteps_Behaviour()), CollectionLiterals.<InternalAction>newArrayList());
      for(final InternalAction callAction_1 : _queryInternalActions) {
        String _setupCalculators_1 = this.setupCalculators(callAction_1);
        _builder.append(_setupCalculators_1);
        _builder.newLineIfNotEmpty();
      }
    }
    return _builder.toString();
  }

  protected String _setupCalculators(final ExternalCallAction action) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("// Old: \"Call \"+this.calledService_ExternalService.interface__OperationSignature.entityName+\".\"+this.calledService_ExternalService.javaSignature()+\" <AssemblyCtx: \\\"+this.assemblyContext.getId()+\\\", CallID: \"+ this.id +\">\"");
    _builder.newLine();
    final String callName = this._sensorsExt.externalCallActionDescription(action.getCalledService_ExternalService(), action);
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("// ExternalCallAction ");
    String _entityName = action.getEntityName();
    _builder.append(_entityName, "\t");
    _builder.append(" (");
    String _id = action.getId();
    _builder.append(_id, "\t");
    _builder.append(")");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    CharSequence _setupCalculatorResponseTime = this.setupCalculatorResponseTime(callName, ("start" + callName), ("end" + callName));
    _builder.append(_setupCalculatorResponseTime, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("if(getModel().getConfiguration().getSimulateFailures()){");
    _builder.newLine();
    _builder.append("\t\t");
    CharSequence _setupCalculatorExecutionResult = this.setupCalculatorExecutionResult(action, callName);
    _builder.append(_setupCalculatorExecutionResult, "\t\t");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("}");
    _builder.newLine();
    return _builder.toString();
  }

  protected String _setupCalculators(final InternalAction action) {
    StringConcatenation _builder = new StringConcatenation();
    {
      EList<InfrastructureCall> _infrastructureCall__Action = action.getInfrastructureCall__Action();
      for(final InfrastructureCall infrastructureCall : _infrastructureCall__Action) {
        final String callName = this._sensorsExt.internalActionDescription(infrastructureCall.getSignature__InfrastructureCall(), action);
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        _builder.append("// InternalAction ");
        String _entityName = action.getEntityName();
        _builder.append(_entityName, "\t");
        _builder.append(" (");
        String _id = action.getId();
        _builder.append(_id, "\t");
        _builder.append(")");
        _builder.newLineIfNotEmpty();
        _builder.append("\t");
        CharSequence _setupCalculatorResponseTime = this.setupCalculatorResponseTime(callName, ("start" + callName), ("end" + callName));
        _builder.append(_setupCalculatorResponseTime, "\t");
        _builder.newLineIfNotEmpty();
      }
    }
    return _builder.toString();
  }

  public String setupCalculators(final Object comp) {
    if (comp instanceof RepositoryComponent) {
      return _setupCalculators((RepositoryComponent)comp);
    } else if (comp instanceof ExternalCallAction) {
      return _setupCalculators((ExternalCallAction)comp);
    } else if (comp instanceof InternalAction) {
      return _setupCalculators((InternalAction)comp);
    } else if (comp instanceof EntryLevelSystemCall) {
      return _setupCalculators((EntryLevelSystemCall)comp);
    } else if (comp instanceof UsageScenario) {
      return _setupCalculators((UsageScenario)comp);
    } else if (comp instanceof ResourceDemandingSEFF) {
      return _setupCalculators((ResourceDemandingSEFF)comp);
    } else if (comp instanceof ServiceEffectSpecification) {
      return _setupCalculators((ServiceEffectSpecification)comp);
    } else {
      throw new IllegalArgumentException("Unhandled parameter types: " +
        Arrays.<Object>asList(comp).toString());
    }
  }
}
